API docs for “spamfighter.txjsonrpc.web.jsonrpc.QueryProtocol”

# Class s.t.w.j.QueryProtocol(http.HTTPClient):

Part of spamfighter.txjsonrpc.web.jsonrpc View Source View In Hierarchy

Undocumented

Method | connectionMade | Undocumented
Method | handleStatus | Undocumented
Method | handleResponse | Undocumented

def connectionMade(self): (source)
Undocumented
def handleStatus(self, version, status, message): (source)
Undocumented
def handleResponse(self, contents): (source)
Undocumented